==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/logz/kotlin/inputs/GetSubAccountTagRulePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logz.kotlin.inputs

import com.pulumi.azurenative.logz.inputs.GetSubAccountTagRulePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property monitorName Monitor resource name
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property ruleSetName
 * @property subAccountName Sub Account resource name
 */
public data class GetSubAccountTagRulePlainArgs(
    public val monitorName: String,
    public val resourceGroupName: String,
    public val ruleSetName: String,
    public val subAccountName: String,
) : ConvertibleToJava<com.pulumi.azurenative.logz.inputs.GetSubAccountTagRulePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.logz.inputs.GetSubAccountTagRulePlainArgs =
        com.pulumi.azurenative.logz.inputs.GetSubAccountTagRulePlainArgs.builder()
            .monitorName(monitorName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .ruleSetName(ruleSetName.let({ args0 -> args0 }))
            .subAccountName(subAccountName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSubAccountTagRulePlainArgs].
 */
@PulumiTagMarker
public class GetSubAccountTagRulePlainArgsBuilder internal constructor() {
    private var monitorName: String? = null

    private var resourceGroupName: String? = null

    private var ruleSetName: String? = null

    private var subAccountName: String? = null

    /**
     * @param value Monitor resource name
     */
    @JvmName("umoaqlxupealyake")
    public suspend fun monitorName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.monitorName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("hpsbimsqletykquy")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value
     */
    @JvmName("krnqbrjjrigtwntf")
    public suspend fun ruleSetName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.ruleSetName = mapped
    }

    /**
     * @param value Sub Account resource name
     */
    @JvmName("eqkbpnbggumtygmo")
    public suspend fun subAccountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.subAccountName = mapped
    }

    internal fun build(): GetSubAccountTagRulePlainArgs = GetSubAccountTagRulePlainArgs(
        monitorName = monitorName ?: throw PulumiNullFieldException("monitorName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        ruleSetName = ruleSetName ?: throw PulumiNullFieldException("ruleSetName"),
        subAccountName = subAccountName ?: throw PulumiNullFieldException("subAccountName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/logz/kotlin/inputs/GetSubAccountTagRulePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logz.kotlin.inputs

import com.pulumi.azurenative.logz.inputs.GetSubAccountTagRulePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property monitorName Monitor resource name
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property ruleSetName
 * @property subAccountName Sub Account resource name
 */
public data class GetSubAccountTagRulePlainArgs(
    public val monitorName: String,
    public val resourceGroupName: String,
    public val ruleSetName: String,
    public val subAccountName: String,
) : ConvertibleToJava<com.pulumi.azurenative.logz.inputs.GetSubAccountTagRulePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.logz.inputs.GetSubAccountTagRulePlainArgs =
        com.pulumi.azurenative.logz.inputs.GetSubAccountTagRulePlainArgs.builder()
            .monitorName(monitorName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .ruleSetName(ruleSetName.let({ args0 -> args0 }))
            .subAccountName(subAccountName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSubAccountTagRulePlainArgs].
 */
@PulumiTagMarker
public class GetSubAccountTagRulePlainArgsBuilder internal constructor() {
    private var monitorName: String? = null

    private var resourceGroupName: String? = null

    private var ruleSetName: String? = null

    private var subAccountName: String? = null

    /**
     * @param value Monitor resource name
     */
    @JvmName("sugfvfjenpdeuuwh")
    public suspend fun monitorName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.monitorName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("xatrrvxecdbjiuea")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value
     */
    @JvmName("dloufwdbykgfvtle")
    public suspend fun ruleSetName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.ruleSetName = mapped
    }

    /**
     * @param value Sub Account resource name
     */
    @JvmName("jimvoyvgmtuxqghs")
    public suspend fun subAccountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.subAccountName = mapped
    }

    internal fun build(): GetSubAccountTagRulePlainArgs = GetSubAccountTagRulePlainArgs(
        monitorName = monitorName ?: throw PulumiNullFieldException("monitorName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        ruleSetName = ruleSetName ?: throw PulumiNullFieldException("ruleSetName"),
        subAccountName = subAccountName ?: throw PulumiNullFieldException("subAccountName"),
    )
}
